@@ -41,7 +41,7 @@ class DummySubprocess:
         """
         self.PIPE="pipe"
         self.STDOUT="stdout"
-        self.mswindows = (sys.platform[0:3] == "win")
+	self.mswindows = (sys.platform[0:3] == "win") or (sys.platform[0:4] == 'java')
         self.tempfile = None
         self.stdout = None
 
@@ -91,7 +91,7 @@ class DummySubprocess:
 if sys.version_info[0:2] < (2,4):
    subprocess = DummySubprocess()
 
-if sys.version_info[0:2] >= (2,5):
+if sys.version_info[0:2] >= (2,5) and subprocess.mswindows:
    import ctypes
 
 def kill_process(pid, sig=signal.SIGTERM, verbose=False):
@@ -218,7 +218,7 @@ def X_read_data(stream, ostr1, ostr2):
 # After this is finished, we can get the output from this command from
 # the process.stdout file descriptor.
 #
-def run_command(cmd, outfile=None, cwd=None, ostream=None, stdout=None, stderr=None, valgrind=False, valgrind_log=None, valgrind_options=None, memmon=False, env=None, define_signal_handlers=True, verbose=True, timelimit=None, tee=None, ignore_output=False, shell=True):
+def run_command(cmd, outfile=None, cwd=None, ostream=None, stdout=None, stderr=None, valgrind=False, valgrind_log=None, valgrind_options=None, memmon=False, env=None, define_signal_handlers=True, verbose=True, timelimit=None, tee=None, ignore_output=False, shell=True, thread_reader=_read_data):
     #
     # Move to the specified working directory
     #
@@ -286,12 +286,12 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdout=None, stderr=N
     if define_signal_handlers:
         if verbose:
             signal.signal(signal.SIGINT, verbose_signal_handler)
-            if sys.platform[0:3] != "win":
+	    if sys.platform[0:3] != "win" and sys.platform[0:4] != 'java':
                 signal.signal(signal.SIGHUP, verbose_signal_handler)
             signal.signal(signal.SIGTERM, verbose_signal_handler)
         else:
             signal.signal(signal.SIGINT, signal_handler)
-            if sys.platform[0:3] != "win":
+	    if sys.platform[0:3] != "win" and sys.platform[0:4] != 'java':
                 signal.signal(signal.SIGHUP, signal_handler)
             signal.signal(signal.SIGTERM, signal_handler)
     rc = -1
@@ -397,13 +397,18 @@ class SubprocessMngr(object):
         #
         # Launch subprocess using a subprocess.Popen object
         #
-        if subprocess.mswindows:
+	if subprocess.mswindows:
            #
            # Launch without console on MSWindows
            #
            startupinfo = subprocess.STARTUPINFO()
            startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
            self.process = subprocess.Popen(cmd.strip(), stdout=stdout, stderr=stderr, startupinfo=startupinfo, env=env, bufsize=bufsize, shell=shell)
+        elif False:   # subprocess.jython:
+           #
+           # Launch from Jython
+           #
+           self.process = subprocess.Popen(cmd.strip(), stdout=stdout, stderr=stderr, env=env, bufsize=bufsize, shell=shell)
         else:
            #
            # Launch on *nix
